==> haskell-aeson-2.1.2.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.1.2.1
visibility:           public
id:                   aeson-2.1.2.1-8pX4IwvbwpcwXiIiReOQk
key:                  aeson-2.1.2.1-8pX4IwvbwpcwXiIiReOQk
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  91643b84dc1791a3f0c67bb84b02debe
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Tokens
    Data.Aeson.Encoding Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Key
    Data.Aeson.KeyMap Data.Aeson.Parser Data.Aeson.Parser.Internal
    Data.Aeson.QQ.Simple Data.Aeson.TH Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Internal Data.Aeson.Encoding.Builder
    Data.Aeson.Internal.ByteString Data.Aeson.Internal.Functions
    Data.Aeson.Internal.Integer Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Word8
    Data.Aeson.Parser.Time Data.Aeson.Parser.Unescape
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.1.2.1-8pX4IwvbwpcwXiIiReOQk
depends:
    OneTuple-0.4.1.1-IVAEQWZp76d1TVzpZm0ZAR
    QuickCheck-2.14.3-JggVBRSlKYhHS3I1VorUGb
    attoparsec-0.14.4-DGiM2cMH1LKFsy4siuUEV5 base-4.17.2.1
    base-compat-batteries-0.12.2-3D1jXZwjuV87HrupJLnpAk
    bytestring-0.11.5.3 containers-0.6.7
    data-fix-0.3.2-LJkVTlruMVWHKEYCUgbVkZ deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    generically-0.1.1-8wbsVPSe8Cd3FdexqvQXN4 ghc-prim-0.9.1
    hashable-1.4.4.0-3qP5TxmiOmVGP173jSDFZO
    indexed-traversable-0.1.4-LRR0UyYa0908dAB2v7mfx4
    primitive-0.7.4.0-KqFD2LgtKT625pNAu5KXoF
    scientific-0.3.7.0-D2shAS6j7tCClWMfBXaB6J
    semialign-1.3-4s8GajainLF3YlKncYwpVd
    strict-0.5-8W8VLKhEyTcDaJNsl1PlSG
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2 text-short-0.1.6-5fV03y0dxlgK2EXuArPGo6
    th-abstraction-0.4.5.0-EtQVnbIEkAX5f6KN9Uwjhw
    these-1.2-HZ5fm7WKAhkBIYhKTf2haY time-1.12.2
    time-compat-1.9.6.1-4yPmIY6XgWvHpPVb8f6emT
    unordered-containers-0.2.20-8U9CBLajvKUXcrLJVqNaj
    uuid-types-1.0.6-JS6rx1kZyoB2Z5njRVbtJ1
    vector-0.13.1.0-3m7HMvWbOJNDnUiYgFdHrI
    witherable-0.4.2-BJc08x14ujN1eW96rS6WHY

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-2.1.2.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.1.2.1
visibility:           public
id:                   aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3
key:                  aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  27aca11c1f921b11b0b1629279173c9f
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Tokens
    Data.Aeson.Encoding Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Key
    Data.Aeson.KeyMap Data.Aeson.Parser Data.Aeson.Parser.Internal
    Data.Aeson.QQ.Simple Data.Aeson.TH Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Internal Data.Aeson.Encoding.Builder
    Data.Aeson.Internal.ByteString Data.Aeson.Internal.Functions
    Data.Aeson.Internal.Integer Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Word8
    Data.Aeson.Parser.Time Data.Aeson.Parser.Unescape
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3
depends:
    OneTuple-0.4.1.1-LakrX5uoHbwz8SCarqPdB
    QuickCheck-2.14.3-DOFi1GQ9eE04hBoMxr6sJJ
    attoparsec-0.14.4-GPSHKdrOxNAHtLNPx9PvVS base-4.17.2.1
    base-compat-batteries-0.12.2-GkmTCtsPQdM6qmnogRrRfk
    bytestring-0.11.5.3 containers-0.6.7
    data-fix-0.3.2-JNkfgh3sBrmALE891C7vSD deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    generically-0.1.1-9w2q4iizRBOJnOlbRxAC58 ghc-prim-0.9.1
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig
    indexed-traversable-0.1.4-3wYYO2pxMt36ZUEwKa9bh7
    primitive-0.7.4.0-GWGNy3IYYzTHqwC4kY0YCL
    scientific-0.3.7.0-Jh9tJE2sLMpFL2bSsP8DMA
    semialign-1.3-3rstZr6bhTj8SA3W5ridQy
    strict-0.5-KlRzlmDKfcv6PjWiysU0B5
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2 text-short-0.1.6-LHOZ8YG3dHr4Bc2V2LTWU4
    th-abstraction-0.4.5.0-EtQVnbIEkAX5f6KN9Uwjhw
    these-1.2-JqsyjIKe1Xu8Mf1MdYefSY time-1.12.2
    time-compat-1.9.6.1-KaJ6EnR2cP13bltOdWho5D
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    uuid-types-1.0.6-IQyEC4RLNlX9sNuZIMNyMl
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD
    witherable-0.4.2-7ZyKreY3ZgZ5BCIlPxBobD

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
